# coding: utf-8

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic.v1 import BaseModel, Field, StrictStr, conlist

class EmailNotificationTypeResponse(BaseModel):
    """
    Holds readonly information about an Email notification  # noqa: E501
    """
    type: Optional[StrictStr] = Field(None, description="The type of delivery mechanism for this notification")
    subject: Optional[StrictStr] = Field(None, description="The subject of the email")
    plain_text_body: Optional[StrictStr] = Field(None, alias="plainTextBody", description="The plain text body of the email")
    html_body: Optional[StrictStr] = Field(None, alias="htmlBody", description="The HTML body of the email (if any)")
    email_address_to: Optional[conlist(StrictStr)] = Field(None, alias="emailAddressTo", description="'To' recipients of the email")
    email_address_cc: Optional[conlist(StrictStr)] = Field(None, alias="emailAddressCc", description="'Cc' recipients of the email")
    email_address_bcc: Optional[conlist(StrictStr)] = Field(None, alias="emailAddressBcc", description="'Bcc' recipients of the email")
    __properties = ["type", "subject", "plainTextBody", "htmlBody", "emailAddressTo", "emailAddressCc", "emailAddressBcc"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EmailNotificationTypeResponse:
        """Create an instance of EmailNotificationTypeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if type (nullable) is None
        # and __fields_set__ contains the field
        if self.type is None and "type" in self.__fields_set__:
            _dict['type'] = None

        # set to None if subject (nullable) is None
        # and __fields_set__ contains the field
        if self.subject is None and "subject" in self.__fields_set__:
            _dict['subject'] = None

        # set to None if plain_text_body (nullable) is None
        # and __fields_set__ contains the field
        if self.plain_text_body is None and "plain_text_body" in self.__fields_set__:
            _dict['plainTextBody'] = None

        # set to None if html_body (nullable) is None
        # and __fields_set__ contains the field
        if self.html_body is None and "html_body" in self.__fields_set__:
            _dict['htmlBody'] = None

        # set to None if email_address_to (nullable) is None
        # and __fields_set__ contains the field
        if self.email_address_to is None and "email_address_to" in self.__fields_set__:
            _dict['emailAddressTo'] = None

        # set to None if email_address_cc (nullable) is None
        # and __fields_set__ contains the field
        if self.email_address_cc is None and "email_address_cc" in self.__fields_set__:
            _dict['emailAddressCc'] = None

        # set to None if email_address_bcc (nullable) is None
        # and __fields_set__ contains the field
        if self.email_address_bcc is None and "email_address_bcc" in self.__fields_set__:
            _dict['emailAddressBcc'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EmailNotificationTypeResponse:
        """Create an instance of EmailNotificationTypeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EmailNotificationTypeResponse.parse_obj(obj)

        _obj = EmailNotificationTypeResponse.parse_obj({
            "type": obj.get("type"),
            "subject": obj.get("subject"),
            "plain_text_body": obj.get("plainTextBody"),
            "html_body": obj.get("htmlBody"),
            "email_address_to": obj.get("emailAddressTo"),
            "email_address_cc": obj.get("emailAddressCc"),
            "email_address_bcc": obj.get("emailAddressBcc")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, Optional
from pydantic.v1 import BaseModel, Field, StrictStr, constr, validator
from lusid_notifications.models.notification_type_response import NotificationTypeResponse

class Notification(BaseModel):
    """
    A notification object  # noqa: E501
    """
    notification_id: constr(strict=True, min_length=1) = Field(..., alias="notificationId", description="The identifier of the notification")
    display_name: constr(strict=True, max_length=64, min_length=0) = Field(..., alias="displayName", description="The name of the notification")
    description: Optional[constr(strict=True, max_length=512, min_length=1)] = Field(None, description="The summary of the services provided by the notification")
    notification_type: NotificationTypeResponse = Field(..., alias="notificationType")
    created_at: datetime = Field(..., alias="createdAt", description="The time at which the subscription was made")
    user_id_created: constr(strict=True, min_length=1) = Field(..., alias="userIdCreated", description="The user who made the subscription")
    modified_at: datetime = Field(..., alias="modifiedAt", description="The time at which the subscription was last modified")
    user_id_modified: constr(strict=True, min_length=1) = Field(..., alias="userIdModified", description="The user who last modified the subscription")
    href: Optional[StrictStr] = Field(None, description="A URI for retrieving this notification")
    __properties = ["notificationId", "displayName", "description", "notificationType", "createdAt", "userIdCreated", "modifiedAt", "userIdModified", "href"]

    @validator('display_name')
    def display_name_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[\s\S]*$", value):
            raise ValueError(r"must validate the regular expression /^[\s\S]*$/")
        return value

    @validator('description')
    def description_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[\s\S]*$", value):
            raise ValueError(r"must validate the regular expression /^[\s\S]*$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Notification:
        """Create an instance of Notification from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of notification_type
        if self.notification_type:
            _dict['notificationType'] = self.notification_type.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict['description'] = None

        # set to None if href (nullable) is None
        # and __fields_set__ contains the field
        if self.href is None and "href" in self.__fields_set__:
            _dict['href'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Notification:
        """Create an instance of Notification from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Notification.parse_obj(obj)

        _obj = Notification.parse_obj({
            "notification_id": obj.get("notificationId"),
            "display_name": obj.get("displayName"),
            "description": obj.get("description"),
            "notification_type": NotificationTypeResponse.from_dict(obj.get("notificationType")) if obj.get("notificationType") is not None else None,
            "created_at": obj.get("createdAt"),
            "user_id_created": obj.get("userIdCreated"),
            "modified_at": obj.get("modifiedAt"),
            "user_id_modified": obj.get("userIdModified"),
            "href": obj.get("href")
        })
        return _obj



# coding: utf-8

"""
    FINBOURNE Notifications API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic.v1 import BaseModel, Field, StrictStr, conlist
from lusid_notifications.models.event_field_definition import EventFieldDefinition

class EventTypeSchema(BaseModel):
    """
    An EventType object  # noqa: E501
    """
    id: Optional[StrictStr] = Field(None, description="The identifier of the event type")
    display_name: Optional[StrictStr] = Field(None, alias="displayName", description="Identifier name of the event")
    description: Optional[StrictStr] = Field(None, description="The summary of the event")
    application: Optional[StrictStr] = Field(None, description="The application associated with the event")
    header_schema: Optional[conlist(EventFieldDefinition)] = Field(None, alias="headerSchema", description="The header schema for the event type")
    body_schema: Optional[conlist(EventFieldDefinition)] = Field(None, alias="bodySchema", description="The body schema for the event type")
    href: Optional[StrictStr] = Field(None, description="A URI for retrieving this schema")
    __properties = ["id", "displayName", "description", "application", "headerSchema", "bodySchema", "href"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EventTypeSchema:
        """Create an instance of EventTypeSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "header_schema",
                            "body_schema",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in header_schema (list)
        _items = []
        if self.header_schema:
            for _item in self.header_schema:
                if _item:
                    _items.append(_item.to_dict())
            _dict['headerSchema'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in body_schema (list)
        _items = []
        if self.body_schema:
            for _item in self.body_schema:
                if _item:
                    _items.append(_item.to_dict())
            _dict['bodySchema'] = _items
        # set to None if id (nullable) is None
        # and __fields_set__ contains the field
        if self.id is None and "id" in self.__fields_set__:
            _dict['id'] = None

        # set to None if display_name (nullable) is None
        # and __fields_set__ contains the field
        if self.display_name is None and "display_name" in self.__fields_set__:
            _dict['displayName'] = None

        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict['description'] = None

        # set to None if application (nullable) is None
        # and __fields_set__ contains the field
        if self.application is None and "application" in self.__fields_set__:
            _dict['application'] = None

        # set to None if header_schema (nullable) is None
        # and __fields_set__ contains the field
        if self.header_schema is None and "header_schema" in self.__fields_set__:
            _dict['headerSchema'] = None

        # set to None if body_schema (nullable) is None
        # and __fields_set__ contains the field
        if self.body_schema is None and "body_schema" in self.__fields_set__:
            _dict['bodySchema'] = None

        # set to None if href (nullable) is None
        # and __fields_set__ contains the field
        if self.href is None and "href" in self.__fields_set__:
            _dict['href'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EventTypeSchema:
        """Create an instance of EventTypeSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EventTypeSchema.parse_obj(obj)

        _obj = EventTypeSchema.parse_obj({
            "id": obj.get("id"),
            "display_name": obj.get("displayName"),
            "description": obj.get("description"),
            "application": obj.get("application"),
            "header_schema": [EventFieldDefinition.from_dict(_item) for _item in obj.get("headerSchema")] if obj.get("headerSchema") is not None else None,
            "body_schema": [EventFieldDefinition.from_dict(_item) for _item in obj.get("bodySchema")] if obj.get("bodySchema") is not None else None,
            "href": obj.get("href")
        })
        return _obj
